The raw data (before histogramming) to estimate a mixture density
for.
df
The number of degrees of freedom to use in the natural spline
in fitting the mixture density.
knots
The positions of the knots to use in the natural spline fit.
Value
fdr The estimated local fdr function (can be called on numeric vectors).pi0 The estimated proportion of data that lies in the poisson componentlambda0 The estimated parameter for the poisson component.f0 The estimated null density function (can be called on numeric
vectors.)f The estimated mixture density function (can be called on numeric
vectors.)